# *AutoVariate: A Python Package to build Variational Autoencoders* 

###AutoVariate is a python module to make the usage of Variational Autoencoders more streamlined


###Installing AutoVariate

```
pip3 install autovariate
```





